pub enum LoopError {
InvalidState(String),
Cancelled,
Provider(String),
Tool(ToolError),
Compaction(String),
Unsupported(String),
}Expand description
Errors that can occur while driving the agent loop.
Variants
InvalidState(String)
The driver was in an unexpected state for the requested operation.
Cancelled
The current turn was cancelled via the CancellationHandle.
Provider(String)
An error originating from the model provider.
Tool(ToolError)
An error originating from tool execution.
Compaction(String)
An error that occurred during transcript compaction.
Unsupported(String)
The requested operation is not supported.