pub enum PromptCacheMode {
Disabled,
BestEffort,
Required,
}Expand description
Strength of a prompt-cache request.
BestEffort lets adapters ignore unsupported controls while still using
any provider-native automatic caching they support. Required upgrades
unsupported cache requests into provider errors.
Variants
Disabled
Disable prompt caching for this request.
BestEffort
Use caching when the provider can honor the request.
Required
Fail the turn if the provider cannot honor the request.