PromptCacheRequest

Struct PromptCacheRequest 

pub struct PromptCacheRequest {
    pub mode: PromptCacheMode,
    pub strategy: PromptCacheStrategy,
    pub retention: Option<PromptCacheRetention>,
    pub key: Option<String>,
}
Prompt caching request sent alongside a turn.

Fields

mode: PromptCacheMode

Strength of the caching request.

strategy: PromptCacheStrategy

Automatic or explicit caching strategy.

retention: Option<PromptCacheRetention>

Optional provider-neutral retention hint.

key: Option<String>

Optional provider cache key or routing key.

Implementations

Source

impl PromptCacheRequest

pub fn automatic() -> Self

Builds a best-effort automatic cache request.

pub fn automatic_required() -> Self

Builds a required automatic cache request.

pub fn explicit( breakpoints: impl IntoIterator<Item = PromptCacheBreakpoint>, ) -> Self

Builds a best-effort explicit cache request.

pub fn explicit_required( breakpoints: impl IntoIterator<Item = PromptCacheBreakpoint>, ) -> Self

Builds a required explicit cache request.

pub fn disabled() -> Self

Builds a disabled cache request.

pub fn best_effort(strategy: PromptCacheStrategy) -> Self

Builds a best-effort cache request with the given strategy.

pub fn required(strategy: PromptCacheStrategy) -> Self

Builds a required cache request with the given strategy.

pub fn with_mode(self, mode: PromptCacheMode) -> Self

Overrides the request mode.

pub fn with_strategy(self, strategy: PromptCacheStrategy) -> Self

Overrides the request strategy.

pub fn with_retention(self, retention: PromptCacheRetention) -> Self

Applies a provider-neutral retention hint.

pub fn with_key(self, key: impl Into<String>) -> Self

Applies a provider cache key or routing key.

pub fn without_retention(self) -> Self

Clears any provider-neutral retention hint.

pub fn without_key(self) -> Self

Clears any provider cache key or routing key.

pub fn is_enabled(&self) -> bool

Returns true when caching should be active for this request.