pub struct PromptCacheRequest {
pub mode: PromptCacheMode,
pub strategy: PromptCacheStrategy,
pub retention: Option<PromptCacheRetention>,
pub key: Option<String>,
}Expand description
Prompt caching request sent alongside a turn.
Fields
mode: PromptCacheModeStrength of the caching request.
strategy: PromptCacheStrategyAutomatic or explicit caching strategy.
retention: Option<PromptCacheRetention>Optional provider-neutral retention hint.
key: Option<String>Optional provider cache key or routing key.
Implementations
Sourceimpl PromptCacheRequest
impl PromptCacheRequest
Sourcepub fn automatic_required() -> Self
pub fn automatic_required() -> Self
Builds a required automatic cache request.
Sourcepub fn explicit(
breakpoints: impl IntoIterator<Item = PromptCacheBreakpoint>,
) -> Self
pub fn explicit( breakpoints: impl IntoIterator<Item = PromptCacheBreakpoint>, ) -> Self
Builds a best-effort explicit cache request.
Sourcepub fn explicit_required(
breakpoints: impl IntoIterator<Item = PromptCacheBreakpoint>,
) -> Self
pub fn explicit_required( breakpoints: impl IntoIterator<Item = PromptCacheBreakpoint>, ) -> Self
Builds a required explicit cache request.
Sourcepub fn best_effort(strategy: PromptCacheStrategy) -> Self
pub fn best_effort(strategy: PromptCacheStrategy) -> Self
Builds a best-effort cache request with the given strategy.
Sourcepub fn required(strategy: PromptCacheStrategy) -> Self
pub fn required(strategy: PromptCacheStrategy) -> Self
Builds a required cache request with the given strategy.
Sourcepub fn with_mode(self, mode: PromptCacheMode) -> Self
pub fn with_mode(self, mode: PromptCacheMode) -> Self
Overrides the request mode.
Sourcepub fn with_strategy(self, strategy: PromptCacheStrategy) -> Self
pub fn with_strategy(self, strategy: PromptCacheStrategy) -> Self
Overrides the request strategy.
Sourcepub fn with_retention(self, retention: PromptCacheRetention) -> Self
pub fn with_retention(self, retention: PromptCacheRetention) -> Self
Applies a provider-neutral retention hint.
Sourcepub fn with_key(self, key: impl Into<String>) -> Self
pub fn with_key(self, key: impl Into<String>) -> Self
Applies a provider cache key or routing key.
Sourcepub fn without_retention(self) -> Self
pub fn without_retention(self) -> Self
Clears any provider-neutral retention hint.
Sourcepub fn without_key(self) -> Self
pub fn without_key(self) -> Self
Clears any provider cache key or routing key.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true when caching should be active for this request.